# Band\t Software Developement Kit
#### Common tools in one place.


This library is written for economy time of developement.
Common usage tools in one touch. GPL-3.0 license.
The library contains the next packages:

### GitHub Repository:
<a href=https://github.com/4ngry-GitHub/banditsdk>Click here</a>

### Authors nicnames:
<ul>
<li> <a href=https://github.com/4ngry-GitHub>AngryDanny+</a> </li>
<li> <a href=https://github.com/NazikXY>N_XY</a> </li>
</ul>

<ul>
<li><a href=https://docs.pydantic.dev/>Pydantic</a></li>
<li><a href=https://www.sqlalchemy.org/>SqlAlchemy</a></li>
</ul>

